<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * Icelandic language file
 *
 * @author Hrannar Baldursson <hrannar.baldursson@gmail.com>
 * @author Ólafur Gunnlaugsson <oli@audiotools.com>
 * @author Erik Bjørn Pedersen <erik.pedersen@shaw.ca>
 */
$lang['menu']                  = 'Stillingar';
$lang['error']                 = 'Stillingum ekki breitt þar sem rangar upplýsingar voru settar inn, vinsamlegast yfirfarið stillingar merktar með rauðu';
$lang['updated']               = 'Stillingum breitt';
$lang['nochoice']              = '(engir aðrir valmöguleikar fyrir hendi)';
$lang['_display']              = 'Skjástillingar';
$lang['_anti_spam']            = 'Stillingar gegn ruslpósti';
$lang['_editing']              = 'Útgáfastillingar';
$lang['title']                 = 'Heiti wikis';
$lang['lang']                  = 'Tungumál';
$lang['template']              = 'Mát';
$lang['recent']                = 'Nýlegar breytingar';
$lang['breadcrumbs']           = 'Fjöldi brauðmolar';
$lang['youarehere']            = 'Stigveldisá brauðmolar';
$lang['typography']            = 'Gera stað fyrir leturgerðir';
$lang['dformat']               = 'Dagsetningarsnið (sjá PHP-aðgerð <a href="http://php.net/strftime">strftime</a>)';
$lang['signature']             = 'Undirskrift';
$lang['passcrypt']             = 'Dulritunaraðferð aðgangsorðs';
$lang['defaultgroup']          = 'Sjálfgefinn hópur';
$lang['superuser']             = 'Hópur kerfisstjóra ';
$lang['profileconfirm']        = 'Staðfestu breytingar með aðgangsorði';
$lang['gdlib']                 = 'Útgáfa af GD Lib';
$lang['jpg_quality']           = 'JPG gæðastilling (0-100)';
$lang['mailfrom']              = 'Rafpóstfang fyrir sjálfvirkar póstsendingar';
$lang['proxy____host']         = 'Heiti staðgengilsþjóns';
$lang['proxy____port']         = 'Staðgengilstengi';
$lang['proxy____user']         = 'Staðgengill notendanafn';
$lang['proxy____pass']         = 'Staðgengilsaðgangsorð';
$lang['proxy____ssl']          = 'Nýta SSL til að tengjast staðgengill';
$lang['license_o_']            = 'Ekkert valið';
$lang['typography_o_0']        = 'engin';
$lang['userewrite_o_0']        = 'engin';
$lang['deaccent_o_0']          = 'slökkt';
$lang['deaccent_o_1']          = 'fjarlægja broddi';
$lang['deaccent_o_2']          = 'gera rómverskt';
$lang['gdlib_o_0']             = 'GD Lib ekki til staðar';
$lang['gdlib_o_1']             = 'Útgáfa 1,x';
$lang['gdlib_o_2']             = 'Sjálfvirk leit';
$lang['rss_type_o_rss']        = 'RSS 0,91';
$lang['rss_type_o_rss1']       = 'RSS 1,0';
$lang['rss_type_o_rss2']       = 'RSS 2,0';
$lang['rss_type_o_atom']       = 'Atom 0,3';
$lang['rss_type_o_atom1']      = 'Atom 1,0';
$lang['compression_o_0']       = 'engin';
$lang['showuseras_o_loginname'] = 'Innskránafn';
$lang['showuseras_o_username'] = 'Fullt notendanafn';
$lang['useheading_o_0']        = 'Aldrei';
$lang['useheading_o_1']        = 'Alltaf';
